<?php

namespace Bluesquare\Connect\Commands;

use Bluesquare\Connect\Connect;
use Bluesquare\Connect\ConnectException;
use Bluesquare\Connect\Traits\HasConnectTokens;
use Illuminate\Console\Command;

class RefreshTokens extends Command
{
    protected $signature = 'connect:refresh';

    protected $description = 'Refresh Bluesquare Connect tokens';

    public function handle(Connect $connect)
    {
        $class = config('bconnect.model');

        $has_fields = in_array(HasConnectTokens::class, class_uses($class));

        if (! $has_fields) {
            throw new ConnectException("$class does not implement HasConnectTokens");
        }

        $class::query()->chunks(10, function ($models) use ($connect) {
            $models->each(function ($model) use ($connect) {
                if (! empty($model->connect_refresh_token) && $model->connect_expires_at <= now()->addHour()) {
                    try {
                        $tokens = $connect->getAccessTokenFromRefreshToken($model->connect_refresh_token);
                        $connect->updateUserConnectData($model, $tokens);
                        $model->save();
                    }
                    catch (\Exception $exception) {
                        $this->warn("Failed to refresh model tokens", $model->toArray());
                    }
                }
            });
        });

        $this->info("Tokens refreshed");

        return 0;
    }
}
